<?php

namespace App\Controller;

use App\Entity\Clothes;
use App\Form\ClothesType;
use App\Repository\ClothesRepository;

use App\Entity\Category;
use App\Form\CategoryType;
use App\Repository\CategoryRepository;

use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Session\SessionInterface;
use Symfony\Component\Routing\Annotation\Route;

#[Route('/cart')]
class CartController extends AbstractController
{
    #[Route('/', name: 'app_cart_index', methods: ['GET', 'POST'])]
    public function index(SessionInterface $session, ClothesRepository $clothesRepository)
    {
        $panier = $session->get("panier", []);

        // On "fabrique" les données
        $dataPanier = [];
        $total = 0;

        foreach($panier as $id => $quantite) {
            $clothes = $clothesRepository->find($id);
            $dataPanier[] = [
                "clothes" => $clothes,
                "quantite" => $quantite
            ];
            $total += $clothes->getPrice() * $quantite;
        }

        $categoryRepository = $this->getDoctrine()
                                 ->getRepository(Category::class);  


        return $this->render('cart/index.html.twig', [
            'dataPanier' => $dataPanier,
            'total' => $total,
            'categories' => $categoryRepository->findAll(),
        ]);
    }

    #[Route('/add/{id}', name: 'app_cart_add', methods: ['GET', 'POST'])]
    public function add(Clothes $clothes, SessionInterface $session)
    {
        // On récupère le panier actuel
        $panier = $session->get("panier", []);
        $id = $clothes->getId();
        // dd($panier);
        
        if (!empty($panier[$id])) {
            $panier[$id]++;
        } else {
            $panier[$id] = 1;
        }

        // On sauvegarde dans la session
        $session->set("panier", $panier);
        return $this->redirectToRoute("app_cart_index");
    }

    #[Route('/remove/{id}', name: 'app_cart_remove', methods: ['GET', 'POST'])]
    public function remove(Clothes $clothes, SessionInterface $session)
    {
        // On récupère le panier actuel
        $panier = $session->get("panier", []);
        $id = $clothes->getId();

        if (!empty($panier[$id])) {
            if ($panier[$id] > 1) {
                $panier[$id]--;
            } else {
                unset($panier[$id]);
            }
        }

        // On sauvegarde dans la session
        $session->set("panier", $panier);

        return $this->redirectToRoute("app_cart_index");
    }

    #[Route('/delete/{id}', name: 'app_cart_delete', methods: ['GET', 'POST'])]
    public function delete(Clothes $clothes, SessionInterface $session)
    {
        // On récupère le panier actuel
        $panier = $session->get("panier", []);
        $id = $clothes->getId();

        if (!empty($panier[$id])) {
            if ($panier[$id] > 1) {
                unset($panier[$id]);
            }
        }

        // On sauvegarde dans la session
        $session->set("panier", $panier);

        return $this->redirectToRoute("app_cart_index");
    }
}
