<?php

namespace App\Controller;

use App\Entity\Clothes;
use App\Form\ClothesType;
use App\Repository\ClothesRepository;

use App\Entity\Category;
use App\Form\CategoryType;
use App\Repository\CategoryRepository;

use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

#[Route('/clothes')]
class ClothesController extends AbstractController
{
    #[Route('/', name: 'app_clothes_index', methods: ['GET'])]
    public function index(ClothesRepository $clothesRepository): Response
    {
        $categoryRepository = $this->getDoctrine()
                                 ->getRepository(Category::class);  
        return $this->render('clothes/index.html.twig', [
            'clothes' => $clothesRepository->findAll(),
            'categories' => $categoryRepository->findAll(),
        ]);
    }

    #[Route('/new', name: 'app_clothes_new', methods: ['GET', 'POST'])]
    public function new(Request $request, ClothesRepository $clothesRepository): Response
    {
        $clothes = new Clothes();
        $form = $this->createForm(ClothesType::class, $clothes);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $clothesRepository->save($clothes, true);

            return $this->redirectToRoute('app_clothes_index', [], Response::HTTP_SEE_OTHER);
        }
        $categoryRepository = $this->getDoctrine()
                                 ->getRepository(Category::class); 

        return $this->renderForm('clothes/new.html.twig', [
            'clothes' => $clothes,
            'categories' => $categoryRepository->findAll(),
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_clothes_show', methods: ['GET'])]
    public function show(Clothes $clothes): Response
    {
        return $this->render('clothes/show.html.twig', [
            'clothes' => $clothes,
        ]);
    }

    #[Route('/{id}/edit', name: 'app_clothes_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Clothes $clothes, ClothesRepository $clothesRepository): Response
    {
        $form = $this->createForm(ClothesType::class, $clothes);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $clothesRepository->save($clothes, true);

            return $this->redirectToRoute('app_clothes_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->renderForm('clothes/edit.html.twig', [
            'clothes' => $clothes,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_clothes_delete', methods: ['POST'])]
    public function delete(Request $request, Clothes $clothes, ClothesRepository $clothesRepository): Response
    {
        if ($this->isCsrfTokenValid('delete'.$clothes->getId(), $request->request->get('_token'))) {
            $clothesRepository->remove($clothes, true);
        }

        return $this->redirectToRoute('app_clothes_index', [], Response::HTTP_SEE_OTHER);
    }
}
