<?php

namespace App\Controller;

use App\Entity\Ecurie;
use App\Form\EcurieType;
use App\Repository\EcurieRepository;

use App\Entity\Category;
use App\Form\CategoryType;
use App\Repository\CategoryRepository;

use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;

#[Route('/ecurie')]
class EcurieController extends AbstractController
{
    #[Route('/', name: 'app_ecurie_index', methods: ['GET'])]
    public function index(): Response
    {
        $categoryRepository = $this->getDoctrine()
                                 ->getRepository(Category::class);   
        $ecurieRepository = $this->getDoctrine()
                                 ->getRepository(Ecurie::class);   

        return $this->render('ecurie/index.html.twig', [
            'ecuries' => $ecurieRepository->findAll(),
            'categories' => $categoryRepository->findAll(),
        ]);
    }

    #[Route('/new', name: 'app_ecurie_new', methods: ['GET', 'POST'])]
    public function new(Request $request, EcurieRepository $ecurieRepository): Response
    {
        $ecurie = new Ecurie();
        $form = $this->createForm(EcurieType::class, $ecurie);
        $form->handleRequest($request);

        $categoryRepository = $this->getDoctrine()
                                 ->getRepository(Category::class);   

        if ($form->isSubmitted() && $form->isValid()) {
            $ecurieRepository->save($ecurie, true);

            return $this->redirectToRoute('app_ecurie_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->renderForm('ecurie/new.html.twig', [
            'ecurie' => $ecurie,
            'form' => $form,
            'categories' => $categoryRepository->findAll(),
        ]);
    }

    #[Route('/{id}', name: 'app_ecurie_show', methods: ['GET'])]
    public function show(Ecurie $ecurie): Response
    {
        $categoryRepository = $this->getDoctrine()
                                 ->getRepository(Category::class);   
        return $this->render('ecurie/show.html.twig', [
            'ecurie' => $ecurie,
            'categories' => $categoryRepository->findAll(),
        ]);
    }

    #[Route('/{id}/edit', name: 'app_ecurie_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Ecurie $ecurie, EcurieRepository $ecurieRepository): Response
    {
        $form = $this->createForm(EcurieType::class, $ecurie);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $ecurieRepository->save($ecurie, true);

            return $this->redirectToRoute('app_ecurie_index', [], Response::HTTP_SEE_OTHER);
        }

        return $this->renderForm('ecurie/edit.html.twig', [
            'ecurie' => $ecurie,
            'form' => $form,
        ]);
    }

    #[Route('/{id}', name: 'app_ecurie_delete', methods: ['POST'])]
    public function delete(Request $request, Ecurie $ecurie, EcurieRepository $ecurieRepository): Response
    {
        if ($this->isCsrfTokenValid('delete'.$ecurie->getId(), $request->request->get('_token'))) {
            $ecurieRepository->remove($ecurie, true);
        }

        return $this->redirectToRoute('app_ecurie_index', [], Response::HTTP_SEE_OTHER);
    }
}
